package com.zhyc.module.produce.manage_sheep.service;

import java.util.List;
import com.zhyc.module.produce.manage_sheep.domain.ScChangeVariety;

/**
 * 改品种记录Service接口
 * 
 * @author ruoyi
 * @date 2025-07-24
 */
public interface IScChangeVarietyService 
{
    /**
     * 查询改品种记录
     * 
     * @param id 改品种记录主键
     * @return 改品种记录
     */
    public ScChangeVariety selectScChangeVarietyById(Integer id);

    /**
     * 查询改品种记录列表
     * 
     * @param scChangeVariety 改品种记录
     * @return 改品种记录集合
     */
    public List<ScChangeVariety> selectScChangeVarietyList(ScChangeVariety scChangeVariety);

    /**
     * 新增改品种记录
     * 
     * @param scChangeVariety 改品种记录
     * @return 结果
     */
    public int insertScChangeVariety(ScChangeVariety scChangeVariety);

    /**
     * 修改改品种记录
     * 
     * @param scChangeVariety 改品种记录
     * @return 结果
     */
    public int updateScChangeVariety(ScChangeVariety scChangeVariety);

    /**
     * 批量删除改品种记录
     * 
     * @param ids 需要删除的改品种记录主键集合
     * @return 结果
     */
    public int deleteScChangeVarietyByIds(Integer[] ids);

    /**
     * 删除改品种记录信息
     * 
     * @param id 改品种记录主键
     * @return 结果
     */
    public int deleteScChangeVarietyById(Integer id);

    List<String> searchEarNumbers(String query);
}
